@@ -5,6 +5,7 @@
 #include <boost/date_time/posix_time/posix_time.hpp>
 
 using namespace boost::interprocess;
+namespace pt = boost::posix_time;
 
 
 // [[Rcpp::export]]
@@ -14,33 +15,40 @@ void rcpp_create_semaphore(const char* id, unsigned int value = 0) {
 
 
 // [[Rcpp::export]]
-void rcpp_increment_semaphore(const char* id) {
+void rcpp_sem_post(const char* id) {
   named_semaphore sem(open_only_t(), id);
   sem.post();
 }
 
 
 // [[Rcpp::export]]
-bool rcpp_decrement_semaphore(const char* id, bool wait = true, long seconds = 0) {
-  
+bool rcpp_wait(const char* id) {
   named_semaphore sem(open_only_t(), id);
-  
-  if (wait) {
-    
-    if (seconds == 0) {
-      
-      sem.wait();
-      return true;
-      
-    } else {
-      boost::posix_time::ptime timeout = boost::posix_time::second_clock::universal_time() + boost::posix_time::seconds(seconds);
-      return sem.timed_wait(timeout);
-    }
-    
-  } else {
-    return sem.try_wait();
-  }
-  
+  sem.wait(); //void
+  return true;
+}
+
+
+// [[Rcpp::export]]
+bool rcpp_try_wait(const char* id) {
+  named_semaphore sem(open_only_t(), id);
+  return sem.try_wait();
+}
+
+
+// [[Rcpp::export]]
+bool rcpp_wait_seconds(const char* id, long seconds = 0) {
+  named_semaphore sem(open_only_t(), id);
+  pt::ptime timeout = pt::second_clock::universal_time() + pt::seconds(seconds);
+  return sem.timed_wait(timeout);
+}
+
+
+// [[Rcpp::export]]
+bool rcpp_wait_microseconds(const char* id, long microseconds = 0) {
+  named_semaphore sem(open_only_t(), id);
+  pt::ptime timeout = pt::microsec_clock::universal_time() + pt::microseconds(microseconds);
+  return sem.timed_wait(timeout);
 }
 
 
